@@ -2,10 +2,10 @@ import numpy as np
 import pandas as pd
 from scipy import stats
 from scipy.stats import poisson
-from py_scripts.utility import (gammaGetShapeRate, negbinomGetSizeProb,
+from .utility import (gammaGetShapeRate, negbinomGetSizeProb,
                                 betaGetShapes, evalWith, parseCatFormula,
                                 parseUnifFormula)
-from py_scripts.group_data import trtAssign
+from .group_data import trtAssign
 from patsy.splines import bs
 
 
